==> pulsar-functions-worker-2.9.0-rc-202107231254-sources.jar: org/apache/pulsar/functions/worker/service/api/Workers.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.functions.worker.service.api;

import java.io.IOException;
import java.net.URI;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import org.apache.pulsar.common.functions.WorkerInfo;
import org.apache.pulsar.common.io.ConnectorDefinition;
import org.apache.pulsar.common.policies.data.WorkerFunctionInstanceStats;
import org.apache.pulsar.common.stats.Metrics;
import org.apache.pulsar.functions.worker.WorkerService;

/**
 * The service to manage worker.
 */
public interface Workers<W extends WorkerService> {

    List<WorkerInfo> getCluster(String clientRole);

    WorkerInfo getClusterLeader(String clientRole);

    Map<String, Collection<String>> getAssignments(String clientRole);

    List<Metrics> getWorkerMetrics(final String clientRole);

    List<WorkerFunctionInstanceStats> getFunctionsMetrics(String clientRole) throws IOException;

    List<ConnectorDefinition> getListOfConnectors(String clientRole);

    void rebalance(final URI uri, final String clientRole);

    Boolean isLeaderReady(final String clientRole);

}

==> pulsar-functions-worker-2.10.0-rc-202202152205-sources.jar: org/apache/pulsar/functions/worker/service/api/Workers.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.functions.worker.service.api;

import java.io.IOException;
import java.net.URI;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.pulsar.client.admin.LongRunningProcessStatus;
import org.apache.pulsar.common.functions.WorkerInfo;
import org.apache.pulsar.common.io.ConnectorDefinition;
import org.apache.pulsar.common.policies.data.WorkerFunctionInstanceStats;
import org.apache.pulsar.common.stats.Metrics;
import org.apache.pulsar.functions.worker.WorkerService;

/**
 * The service to manage worker.
 */
public interface Workers<W extends WorkerService> {

    List<WorkerInfo> getCluster(String clientRole);

    WorkerInfo getClusterLeader(String clientRole);

    Map<String, Collection<String>> getAssignments(String clientRole);

    List<Metrics> getWorkerMetrics(final String clientRole);

    List<WorkerFunctionInstanceStats> getFunctionsMetrics(String clientRole) throws IOException;

    List<ConnectorDefinition> getListOfConnectors(String clientRole);

    void rebalance(final URI uri, final String clientRole);

    void drain(final URI uri, final String workerId, final String clientRole, boolean leaderUri);

    LongRunningProcessStatus getDrainStatus(final URI uri, final String workerId, final String clientRole,
                                            boolean leaderUri);

    Boolean isLeaderReady(final String clientRole);

}
